@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2000-2014 Greg Sabino Mullane and others: see the Changes file
+    Copyright (c) 2000-2017 Greg Sabino Mullane and others: see the Changes file
 	Portions Copyright (c) 1997-2000 Edmund Mergl
 	Portions Copyright (c) 1994-1997 Tim Bunce
 	
@@ -37,6 +37,7 @@ struct imp_dbh_st {
 	bool    done_begin;        /* have we done a begin? (e.g. are we in a transaction?) */
 	bool    dollaronly;        /* only consider $1, $2 ... as valid placeholders */
 	bool    nocolons;          /* do not consider :1, :2 ... as valid placeholders */
+	bool    ph_escaped;        /* allow backslash to escape placeholders */
 	bool    expand_array;      /* transform arrays from the db into Perl arrays? Default is 1 */
 	bool    txn_read_only;     /* are we in read-only mode? Set with $dbh->{ReadOnly} */
 
@@ -73,6 +74,15 @@ struct ph_st {
 };
 typedef struct ph_st ph_t;
 
+typedef enum
+	{
+		PLACEHOLDER_NONE,
+		PLACEHOLDER_QUESTIONMARK,
+		PLACEHOLDER_DOLLAR,
+		PLACEHOLDER_COLON
+	} PGPlaceholderType;
+#define PLACEHOLDER_TYPE_COUNT (PLACEHOLDER_COLON + 1)
+
 /* Define sth implementor data structure */
 struct imp_sth_st {
 	dbih_stc_t com;          /* MUST be first element in structure */
@@ -80,12 +90,12 @@ struct imp_sth_st {
 	int    server_prepare;    /* inherited from dbh. 3 states: 0=no 1=yes 2=smart */
 	int    switch_prepared;   /* inherited from dbh */
     int    number_iterations; /* how many times has the statement been executed? Used by switch_prepared */
-	int    placeholder_type;  /* which style is being used 1=? 2=$1 3=:foo */
+	PGPlaceholderType placeholder_type;  /* which style is being used 1=? 2=$1 3=:foo */
 	int    numsegs;           /* how many segments this statement has */
 	int    numphs;            /* how many placeholders this statement has */
 	int    numbound;          /* how many placeholders were explicitly bound by the client, not us */
 	int    cur_tuple;         /* current tuple being fetched */
-	int    rows;              /* number of affected rows */
+	long   rows;              /* number of affected rows */
 	int    async_flag;        /* async? 0=no 1=async 2=cancel 4=wait */
 	int    async_status;      /* 0=no async 1=async started -1=async has been cancelled */
 
@@ -165,13 +175,13 @@ int dbd_st_prepare_sv (SV * sth, imp_sth_t * imp_sth, SV * statement_sv, SV * at
 int dbd_bind_ph (SV * sth, imp_sth_t * imp_sth, SV * ph_name, SV * newvalue, IV sql_type, SV * attribs, int is_inout, IV maxlen);
 
 #define dbd_st_execute pg_st_execute
-int dbd_st_execute (SV * sth, imp_sth_t * imp_sth);
+long dbd_st_execute (SV * sth, imp_sth_t * imp_sth);
 
 #define dbd_st_fetch  pg_st_fetch
 AV * dbd_st_fetch (SV * sth, imp_sth_t * imp_sth);
 
 #define dbd_st_rows pg_st_rows
-int dbd_st_rows (SV * sth, imp_sth_t * imp_sth);
+long dbd_st_rows (SV * sth, imp_sth_t * imp_sth);
 
 #define dbd_st_finish  pg_st_finish
 int dbd_st_finish (SV * sth, imp_sth_t * imp_sth);
@@ -185,6 +195,13 @@ void dbd_st_destroy (SV * sth, imp_sth_t * imp_sth);
 #define dbd_st_blob_read pg_st_blob_read
 int dbd_st_blob_read (SV * sth, imp_sth_t * imp_sth, int lobjId, long offset, long len, SV * destrv, long destoffset);
 
+#define dbd_st_canonical_ids pg_st_canonical_ids
+SV* dbd_st_canonical_ids(SV *sth, imp_sth_t *imp_sth);
+
+#define dbd_st_canonical_names pg_st_canonical_names
+SV* dbd_st_canonical_names(SV *sth, imp_sth_t *imp_sth);
+
+
 /* 
    Everything else should map back to the DBI version, or be handled by Pg.pm
    TODO: Explicitly map out each one.
@@ -201,7 +218,7 @@ SV * pg_rightgraded_sv(pTHX_ SV *input, bool utf8);
 
 SV * pg_stringify_array(SV * input, const char * array_delim, int server_version, bool utf8);
 
-int pg_quickexec (SV *dbh, const char *sql, const int asyncflag);
+long pg_quickexec (SV *dbh, const char *sql, const int asyncflag);
 
 int pg_db_putline (SV *dbh, SV *svbuf);
 
@@ -249,7 +266,7 @@ unsigned int pg_db_lo_import_with_oid (SV *dbh, char *filename, unsigned int lob
 
 int pg_db_lo_export (SV *dbh, unsigned int lobjId, char *filename);
 
-int pg_db_result (SV *h, imp_dbh_t *imp_dbh);
+long pg_db_result (SV *h, imp_dbh_t *imp_dbh);
 
 int pg_db_ready(SV *h, imp_dbh_t *imp_dbh);
 
