@@ -1,6 +1,6 @@
 /*
 
-   Copyright (c) 2003-2015 Greg Sabino Mullane and others: see the Changes file
+   Copyright (c) 2003-2017 Greg Sabino Mullane and others: see the Changes file
 
    You may distribute under the terms of either the GNU General Public
    License or the Artistic License, as specified in the Perl README file.
@@ -374,9 +374,9 @@ char * quote_name(pTHX_ const char *string, STRLEN len, STRLEN *retlen, int estr
 		char ch = *ptr;
 
 		if (
-			(ch < 'a' && ch > 'z')
+			(ch < 'a' || ch > 'z')
 			&& 
-			(ch < '0' && ch > '9')
+			(ch < '0' || ch > '9')
 			&&
 			ch != '_') {
 			safe = DBDPG_FALSE;
