@@ -235,10 +235,6 @@ version: $version
 		$testuser = 'postgres';
 	}
 
-    # non-ASCII parts of the tests assume UTF8
-    $testdsn =~ s/;?\bclient_encoding=[^;]+//;
-    $testdsn .= ';client_encoding=utf8';
-
 	## From here on out, we don't return directly, but save it first
   GETHANDLE: {
 		eval {
@@ -320,6 +316,9 @@ version: $version
 		elsif ($info =~ /(\d+\.\d+)/) {
 			$version = $1;
 		}
+		elsif ($info =~ /(\d+)devel/) { ## Can be 10devel
+			$version = $1;
+		}
 		else {
 			die "No version from initdb?! ($info)\n";
 		}
@@ -342,7 +341,9 @@ version: $version
 		warn "Please wait, creating new database for testing\n";
 		$info = '';
 		eval {
-			$info = qx{$initdb --locale=C -E UTF8 -D $testdir/data 2>&1};
+            my $com = "$initdb --locale=C -E UTF8 -D $testdir/data";
+			$debug and warn" Attempting: $com\n";
+			$info = qx{$com 2>&1};
 		};
 		last GETHANDLE if $@; ## Fail - initdb bad
 
@@ -493,7 +494,7 @@ version: $version
 			$debug and diag qq{Writing to "$conf"};
 			print $cfh "\n\n## DBD::Pg testing parameters\n";
 			print $cfh "port=$testport\n";
-			print $cfh "max_connections=5\n";
+			print $cfh "max_connections=11\n";
 			if ($version >= 8.0) {
 				print $cfh "log_statement = 'all'\n";
 				print $cfh "log_line_prefix = '%m [%p] '\n";
@@ -554,7 +555,7 @@ version: $version
 		}
 
 		## Attempt to connect to this server
-		$testdsn = "dbi:Pg:dbname=postgres;client_encoding=utf8;port=$testport";
+		$testdsn = "dbi:Pg:dbname=postgres;port=$testport";
 		if ($^O =~ /Win32/) {
 			$testdsn .= ';host=localhost';
 		}
@@ -651,6 +652,11 @@ version: $version
 
 	$debug and diag "Got a database handle ($dbh)";
 
+	if (!$arg->{quickreturn} or 1 != $arg->{quickreturn}) {
+		## non-ASCII parts of the tests assume UTF8
+		$dbh->do('SET client_encoding = utf8');
+	}
+
 	if ($arg->{quickreturn}) {
 		$debug and diag 'Returning via quickreturn';
 		return $helpconnect, '', $dbh;
@@ -829,7 +835,7 @@ sub operator_exists {
 
 	my $schema = 'dbd_pg_testschema';
 	my $SQL = 'SELECT 1 FROM pg_operator o, pg_namespace n '.
-		'WHERE oprname=? AND oprleft::regtype::text = ? AND oprright::regtype::text = ?'.
+		'WHERE oprname=? AND oprleft = ?::regtype AND oprright = ?::regtype'.
 			' AND o.oprnamespace = n.oid AND n.nspname = ?';
 	my $sth = $dbh->prepare_cached($SQL);
 	my $count = $sth->execute($opname,$leftarg,$rightarg,$schema);
